"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryProposalRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryProposalRequest = QueryProposalRequest

class QueryProposalResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_FIELD_NUMBER: builtins.int

    @property
    def proposal(self) -> cosmos.gov.v1beta1.gov_pb2.Proposal: ...

    def __init__(self,
        *,
        proposal : typing.Optional[cosmos.gov.v1beta1.gov_pb2.Proposal] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proposal",b"proposal"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal",b"proposal"]) -> None: ...
global___QueryProposalResponse = QueryProposalResponse

class QueryProposalsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_STATUS_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_status: cosmos.gov.v1beta1.gov_pb2.ProposalStatus.V = ...
    voter: typing.Text = ...
    depositor: typing.Text = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        proposal_status : cosmos.gov.v1beta1.gov_pb2.ProposalStatus.V = ...,
        voter : typing.Text = ...,
        depositor : typing.Text = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"depositor",b"depositor",u"pagination",b"pagination",u"proposal_status",b"proposal_status",u"voter",b"voter"]) -> None: ...
global___QueryProposalsRequest = QueryProposalsRequest

class QueryProposalsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSALS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def proposals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Proposal]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        proposals : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Proposal]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"proposals",b"proposals"]) -> None: ...
global___QueryProposalsResponse = QueryProposalsResponse

class QueryVoteRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    voter: typing.Text = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        voter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id",u"voter",b"voter"]) -> None: ...
global___QueryVoteRequest = QueryVoteRequest

class QueryVoteResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTE_FIELD_NUMBER: builtins.int

    @property
    def vote(self) -> cosmos.gov.v1beta1.gov_pb2.Vote: ...

    def __init__(self,
        *,
        vote : typing.Optional[cosmos.gov.v1beta1.gov_pb2.Vote] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"vote",b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"vote",b"vote"]) -> None: ...
global___QueryVoteResponse = QueryVoteResponse

class QueryVotesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryVotesRequest = QueryVotesRequest

class QueryVotesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Vote]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        votes : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Vote]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"votes",b"votes"]) -> None: ...
global___QueryVotesResponse = QueryVotesResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_TYPE_FIELD_NUMBER: builtins.int
    params_type: typing.Text = ...

    def __init__(self,
        *,
        params_type : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params_type",b"params_type"]) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VOTING_PARAMS_FIELD_NUMBER: builtins.int
    DEPOSIT_PARAMS_FIELD_NUMBER: builtins.int
    TALLY_PARAMS_FIELD_NUMBER: builtins.int

    @property
    def voting_params(self) -> cosmos.gov.v1beta1.gov_pb2.VotingParams: ...

    @property
    def deposit_params(self) -> cosmos.gov.v1beta1.gov_pb2.DepositParams: ...

    @property
    def tally_params(self) -> cosmos.gov.v1beta1.gov_pb2.TallyParams: ...

    def __init__(self,
        *,
        voting_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.VotingParams] = ...,
        deposit_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.DepositParams] = ...,
        tally_params : typing.Optional[cosmos.gov.v1beta1.gov_pb2.TallyParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"deposit_params",b"deposit_params",u"tally_params",b"tally_params",u"voting_params",b"voting_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposit_params",b"deposit_params",u"tally_params",b"tally_params",u"voting_params",b"voting_params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryDepositRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...
    depositor: typing.Text = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        depositor : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"depositor",b"depositor",u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryDepositRequest = QueryDepositRequest

class QueryDepositResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DEPOSIT_FIELD_NUMBER: builtins.int

    @property
    def deposit(self) -> cosmos.gov.v1beta1.gov_pb2.Deposit: ...

    def __init__(self,
        *,
        deposit : typing.Optional[cosmos.gov.v1beta1.gov_pb2.Deposit] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"deposit",b"deposit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposit",b"deposit"]) -> None: ...
global___QueryDepositResponse = QueryDepositResponse

class QueryDepositsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryDepositsRequest = QueryDepositsRequest

class QueryDepositsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DEPOSITS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def deposits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Deposit]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        deposits : typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Deposit]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"deposits",b"deposits",u"pagination",b"pagination"]) -> None: ...
global___QueryDepositsResponse = QueryDepositsResponse

class QueryTallyResultRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int = ...

    def __init__(self,
        *,
        proposal_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proposal_id",b"proposal_id"]) -> None: ...
global___QueryTallyResultRequest = QueryTallyResultRequest

class QueryTallyResultResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TALLY_FIELD_NUMBER: builtins.int

    @property
    def tally(self) -> cosmos.gov.v1beta1.gov_pb2.TallyResult: ...

    def __init__(self,
        *,
        tally : typing.Optional[cosmos.gov.v1beta1.gov_pb2.TallyResult] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"tally",b"tally"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tally",b"tally"]) -> None: ...
global___QueryTallyResultResponse = QueryTallyResultResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Connection:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionRequest,
        global___QueryConnectionResponse] = ...

    Connections:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionsRequest,
        global___QueryConnectionsResponse] = ...

    ClientConnections:grpc.UnaryUnaryMultiCallable[
        global___QueryClientConnectionsRequest,
        global___QueryClientConnectionsResponse] = ...

    ConnectionClientState:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionClientStateRequest,
        global___QueryConnectionClientStateResponse] = ...

    ConnectionConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionConsensusStateRequest,
        global___QueryConnectionConsensusStateResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Connection(self,
        request: global___QueryConnectionRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionResponse: ...

    @abc.abstractmethod
    def Connections(self,
        request: global___QueryConnectionsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionsResponse: ...

    @abc.abstractmethod
    def ClientConnections(self,
        request: global___QueryClientConnectionsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryClientConnectionsResponse: ...

    @abc.abstractmethod
    def ConnectionClientState(self,
        request: global___QueryConnectionClientStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionClientStateResponse: ...

    @abc.abstractmethod
    def ConnectionConsensusState(self,
        request: global___QueryConnectionConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionConsensusStateResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import tendermint.crypto.keys_pb2
import tendermint.crypto.proof_pb2
import tendermint.types.params_pb2
import tendermint.types.types_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CheckTxType(metaclass=_CheckTxType):
    V = typing.NewType('V', builtins.int)

global___CheckTxType = CheckTxType

NEW = CheckTxType.V(0)
RECHECK = CheckTxType.V(1)

class _CheckTxType(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CheckTxType.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    NEW = CheckTxType.V(0)
    RECHECK = CheckTxType.V(1)

class EvidenceType(metaclass=_EvidenceType):
    V = typing.NewType('V', builtins.int)

global___EvidenceType = EvidenceType

UNKNOWN = EvidenceType.V(0)
DUPLICATE_VOTE = EvidenceType.V(1)
LIGHT_CLIENT_ATTACK = EvidenceType.V(2)

class _EvidenceType(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[EvidenceType.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    UNKNOWN = EvidenceType.V(0)
    DUPLICATE_VOTE = EvidenceType.V(1)
    LIGHT_CLIENT_ATTACK = EvidenceType.V(2)

class Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ECHO_FIELD_NUMBER: builtins.int
    FLUSH_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    SET_OPTION_FIELD_NUMBER: builtins.int
    INIT_CHAIN_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    BEGIN_BLOCK_FIELD_NUMBER: builtins.int
    CHECK_TX_FIELD_NUMBER: builtins.int
    DELIVER_TX_FIELD_NUMBER: builtins.int
    END_BLOCK_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    LIST_SNAPSHOTS_FIELD_NUMBER: builtins.int
    OFFER_SNAPSHOT_FIELD_NUMBER: builtins.int
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: builtins.int
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: builtins.int

    @property
    def echo(self) -> global___RequestEcho: ...

    @property
    def flush(self) -> global___RequestFlush: ...

    @property
    def info(self) -> global___RequestInfo: ...

    @property
    def set_option(self) -> global___RequestSetOption: ...

    @property
    def init_chain(self) -> global___RequestInitChain: ...

    @property
    def query(self) -> global___RequestQuery: ...

    @property
    def begin_block(self) -> global___RequestBeginBlock: ...

    @property
    def check_tx(self) -> global___RequestCheckTx: ...

    @property
    def deliver_tx(self) -> global___RequestDeliverTx: ...

    @property
    def end_block(self) -> global___RequestEndBlock: ...

    @property
    def commit(self) -> global___RequestCommit: ...

    @property
    def list_snapshots(self) -> global___RequestListSnapshots: ...

    @property
    def offer_snapshot(self) -> global___RequestOfferSnapshot: ...

    @property
    def load_snapshot_chunk(self) -> global___RequestLoadSnapshotChunk: ...

    @property
    def apply_snapshot_chunk(self) -> global___RequestApplySnapshotChunk: ...

    def __init__(self,
        *,
        echo : typing.Optional[global___RequestEcho] = ...,
        flush : typing.Optional[global___RequestFlush] = ...,
        info : typing.Optional[global___RequestInfo] = ...,
        set_option : typing.Optional[global___RequestSetOption] = ...,
        init_chain : typing.Optional[global___RequestInitChain] = ...,
        query : typing.Optional[global___RequestQuery] = ...,
        begin_block : typing.Optional[global___RequestBeginBlock] = ...,
        check_tx : typing.Optional[global___RequestCheckTx] = ...,
        deliver_tx : typing.Optional[global___RequestDeliverTx] = ...,
        end_block : typing.Optional[global___RequestEndBlock] = ...,
        commit : typing.Optional[global___RequestCommit] = ...,
        list_snapshots : typing.Optional[global___RequestListSnapshots] = ...,
        offer_snapshot : typing.Optional[global___RequestOfferSnapshot] = ...,
        load_snapshot_chunk : typing.Optional[global___RequestLoadSnapshotChunk] = ...,
        apply_snapshot_chunk : typing.Optional[global___RequestApplySnapshotChunk] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"apply_snapshot_chunk",b"apply_snapshot_chunk",u"begin_block",b"begin_block",u"check_tx",b"check_tx",u"commit",b"commit",u"deliver_tx",b"deliver_tx",u"echo",b"echo",u"end_block",b"end_block",u"flush",b"flush",u"info",b"info",u"init_chain",b"init_chain",u"list_snapshots",b"list_snapshots",u"load_snapshot_chunk",b"load_snapshot_chunk",u"offer_snapshot",b"offer_snapshot",u"query",b"query",u"set_option",b"set_option",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"apply_snapshot_chunk",b"apply_snapshot_chunk",u"begin_block",b"begin_block",u"check_tx",b"check_tx",u"commit",b"commit",u"deliver_tx",b"deliver_tx",u"echo",b"echo",u"end_block",b"end_block",u"flush",b"flush",u"info",b"info",u"init_chain",b"init_chain",u"list_snapshots",b"list_snapshots",u"load_snapshot_chunk",b"load_snapshot_chunk",u"offer_snapshot",b"offer_snapshot",u"query",b"query",u"set_option",b"set_option",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"value",b"value"]) -> typing.Optional[typing_extensions.Literal["echo","flush","info","set_option","init_chain","query","begin_block","check_tx","deliver_tx","end_block","commit","list_snapshots","offer_snapshot","load_snapshot_chunk","apply_snapshot_chunk"]]: ...
global___Request = Request

class RequestEcho(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    message: typing.Text = ...

    def __init__(self,
        *,
        message : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"message",b"message"]) -> None: ...
global___RequestEcho = RequestEcho

class RequestFlush(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RequestFlush = RequestFlush

class RequestInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    BLOCK_VERSION_FIELD_NUMBER: builtins.int
    P2P_VERSION_FIELD_NUMBER: builtins.int
    version: typing.Text = ...
    block_version: builtins.int = ...
    p2p_version: builtins.int = ...

    def __init__(self,
        *,
        version : typing.Text = ...,
        block_version : builtins.int = ...,
        p2p_version : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block_version",b"block_version",u"p2p_version",b"p2p_version",u"version",b"version"]) -> None: ...
global___RequestInfo = RequestInfo

class RequestSetOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    value: typing.Text = ...

    def __init__(self,
        *,
        key : typing.Text = ...,
        value : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...
global___RequestSetOption = RequestSetOption

class RequestInitChain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TIME_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    CONSENSUS_PARAMS_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    APP_STATE_BYTES_FIELD_NUMBER: builtins.int
    INITIAL_HEIGHT_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    app_state_bytes: builtins.bytes = ...
    initial_height: builtins.int = ...

    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    @property
    def consensus_params(self) -> global___ConsensusParams: ...

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorUpdate]: ...

    def __init__(self,
        *,
        time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        chain_id : typing.Text = ...,
        consensus_params : typing.Optional[global___ConsensusParams] = ...,
        validators : typing.Optional[typing.Iterable[global___ValidatorUpdate]] = ...,
        app_state_bytes : builtins.bytes = ...,
        initial_height : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_params",b"consensus_params",u"time",b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_state_bytes",b"app_state_bytes",u"chain_id",b"chain_id",u"consensus_params",b"consensus_params",u"initial_height",b"initial_height",u"time",b"time",u"validators",b"validators"]) -> None: ...
global___RequestInitChain = RequestInitChain

class RequestQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    PROVE_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    path: typing.Text = ...
    height: builtins.int = ...
    prove: builtins.bool = ...

    def __init__(self,
        *,
        data : builtins.bytes = ...,
        path : typing.Text = ...,
        height : builtins.int = ...,
        prove : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"height",b"height",u"path",b"path",u"prove",b"prove"]) -> None: ...
global___RequestQuery = RequestQuery

class RequestBeginBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    LAST_COMMIT_INFO_FIELD_NUMBER: builtins.int
    BYZANTINE_VALIDATORS_FIELD_NUMBER: builtins.int
    hash: builtins.bytes = ...

    @property
    def header(self) -> tendermint.types.types_pb2.Header: ...

    @property
    def last_commit_info(self) -> global___LastCommitInfo: ...

    @property
    def byzantine_validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Evidence]: ...

    def __init__(self,
        *,
        hash : builtins.bytes = ...,
        header : typing.Optional[tendermint.types.types_pb2.Header] = ...,
        last_commit_info : typing.Optional[global___LastCommitInfo] = ...,
        byzantine_validators : typing.Optional[typing.Iterable[global___Evidence]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"header",b"header",u"last_commit_info",b"last_commit_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"byzantine_validators",b"byzantine_validators",u"hash",b"hash",u"header",b"header",u"last_commit_info",b"last_commit_info"]) -> None: ...
global___RequestBeginBlock = RequestBeginBlock

class RequestCheckTx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TX_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    tx: builtins.bytes = ...
    type: global___CheckTxType.V = ...

    def __init__(self,
        *,
        tx : builtins.bytes = ...,
        type : global___CheckTxType.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tx",b"tx",u"type",b"type"]) -> None: ...
global___RequestCheckTx = RequestCheckTx

class RequestDeliverTx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TX_FIELD_NUMBER: builtins.int
    tx: builtins.bytes = ...

    def __init__(self,
        *,
        tx : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"tx",b"tx"]) -> None: ...
global___RequestDeliverTx = RequestDeliverTx

class RequestEndBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    height: builtins.int = ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height"]) -> None: ...
global___RequestEndBlock = RequestEndBlock

class RequestCommit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RequestCommit = RequestCommit

class RequestListSnapshots(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___RequestListSnapshots = RequestListSnapshots

class RequestOfferSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SNAPSHOT_FIELD_NUMBER: builtins.int
    APP_HASH_FIELD_NUMBER: builtins.int
    app_hash: builtins.bytes = ...

    @property
    def snapshot(self) -> global___Snapshot: ...

    def __init__(self,
        *,
        snapshot : typing.Optional[global___Snapshot] = ...,
        app_hash : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"snapshot",b"snapshot"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_hash",b"app_hash",u"snapshot",b"snapshot"]) -> None: ...
global___RequestOfferSnapshot = RequestOfferSnapshot

class RequestLoadSnapshotChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    CHUNK_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    format: builtins.int = ...
    chunk: builtins.int = ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        format : builtins.int = ...,
        chunk : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunk",b"chunk",u"format",b"format",u"height",b"height"]) -> None: ...
global___RequestLoadSnapshotChunk = RequestLoadSnapshotChunk

class RequestApplySnapshotChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INDEX_FIELD_NUMBER: builtins.int
    CHUNK_FIELD_NUMBER: builtins.int
    SENDER_FIELD_NUMBER: builtins.int
    index: builtins.int = ...
    chunk: builtins.bytes = ...
    sender: typing.Text = ...

    def __init__(self,
        *,
        index : builtins.int = ...,
        chunk : builtins.bytes = ...,
        sender : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunk",b"chunk",u"index",b"index",u"sender",b"sender"]) -> None: ...
global___RequestApplySnapshotChunk = RequestApplySnapshotChunk

class Response(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXCEPTION_FIELD_NUMBER: builtins.int
    ECHO_FIELD_NUMBER: builtins.int
    FLUSH_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    SET_OPTION_FIELD_NUMBER: builtins.int
    INIT_CHAIN_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    BEGIN_BLOCK_FIELD_NUMBER: builtins.int
    CHECK_TX_FIELD_NUMBER: builtins.int
    DELIVER_TX_FIELD_NUMBER: builtins.int
    END_BLOCK_FIELD_NUMBER: builtins.int
    COMMIT_FIELD_NUMBER: builtins.int
    LIST_SNAPSHOTS_FIELD_NUMBER: builtins.int
    OFFER_SNAPSHOT_FIELD_NUMBER: builtins.int
    LOAD_SNAPSHOT_CHUNK_FIELD_NUMBER: builtins.int
    APPLY_SNAPSHOT_CHUNK_FIELD_NUMBER: builtins.int

    @property
    def exception(self) -> global___ResponseException: ...

    @property
    def echo(self) -> global___ResponseEcho: ...

    @property
    def flush(self) -> global___ResponseFlush: ...

    @property
    def info(self) -> global___ResponseInfo: ...

    @property
    def set_option(self) -> global___ResponseSetOption: ...

    @property
    def init_chain(self) -> global___ResponseInitChain: ...

    @property
    def query(self) -> global___ResponseQuery: ...

    @property
    def begin_block(self) -> global___ResponseBeginBlock: ...

    @property
    def check_tx(self) -> global___ResponseCheckTx: ...

    @property
    def deliver_tx(self) -> global___ResponseDeliverTx: ...

    @property
    def end_block(self) -> global___ResponseEndBlock: ...

    @property
    def commit(self) -> global___ResponseCommit: ...

    @property
    def list_snapshots(self) -> global___ResponseListSnapshots: ...

    @property
    def offer_snapshot(self) -> global___ResponseOfferSnapshot: ...

    @property
    def load_snapshot_chunk(self) -> global___ResponseLoadSnapshotChunk: ...

    @property
    def apply_snapshot_chunk(self) -> global___ResponseApplySnapshotChunk: ...

    def __init__(self,
        *,
        exception : typing.Optional[global___ResponseException] = ...,
        echo : typing.Optional[global___ResponseEcho] = ...,
        flush : typing.Optional[global___ResponseFlush] = ...,
        info : typing.Optional[global___ResponseInfo] = ...,
        set_option : typing.Optional[global___ResponseSetOption] = ...,
        init_chain : typing.Optional[global___ResponseInitChain] = ...,
        query : typing.Optional[global___ResponseQuery] = ...,
        begin_block : typing.Optional[global___ResponseBeginBlock] = ...,
        check_tx : typing.Optional[global___ResponseCheckTx] = ...,
        deliver_tx : typing.Optional[global___ResponseDeliverTx] = ...,
        end_block : typing.Optional[global___ResponseEndBlock] = ...,
        commit : typing.Optional[global___ResponseCommit] = ...,
        list_snapshots : typing.Optional[global___ResponseListSnapshots] = ...,
        offer_snapshot : typing.Optional[global___ResponseOfferSnapshot] = ...,
        load_snapshot_chunk : typing.Optional[global___ResponseLoadSnapshotChunk] = ...,
        apply_snapshot_chunk : typing.Optional[global___ResponseApplySnapshotChunk] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"apply_snapshot_chunk",b"apply_snapshot_chunk",u"begin_block",b"begin_block",u"check_tx",b"check_tx",u"commit",b"commit",u"deliver_tx",b"deliver_tx",u"echo",b"echo",u"end_block",b"end_block",u"exception",b"exception",u"flush",b"flush",u"info",b"info",u"init_chain",b"init_chain",u"list_snapshots",b"list_snapshots",u"load_snapshot_chunk",b"load_snapshot_chunk",u"offer_snapshot",b"offer_snapshot",u"query",b"query",u"set_option",b"set_option",u"value",b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"apply_snapshot_chunk",b"apply_snapshot_chunk",u"begin_block",b"begin_block",u"check_tx",b"check_tx",u"commit",b"commit",u"deliver_tx",b"deliver_tx",u"echo",b"echo",u"end_block",b"end_block",u"exception",b"exception",u"flush",b"flush",u"info",b"info",u"init_chain",b"init_chain",u"list_snapshots",b"list_snapshots",u"load_snapshot_chunk",b"load_snapshot_chunk",u"offer_snapshot",b"offer_snapshot",u"query",b"query",u"set_option",b"set_option",u"value",b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"value",b"value"]) -> typing.Optional[typing_extensions.Literal["exception","echo","flush","info","set_option","init_chain","query","begin_block","check_tx","deliver_tx","end_block","commit","list_snapshots","offer_snapshot","load_snapshot_chunk","apply_snapshot_chunk"]]: ...
global___Response = Response

class ResponseException(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ERROR_FIELD_NUMBER: builtins.int
    error: typing.Text = ...

    def __init__(self,
        *,
        error : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"error",b"error"]) -> None: ...
global___ResponseException = ResponseException

class ResponseEcho(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    message: typing.Text = ...

    def __init__(self,
        *,
        message : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"message",b"message"]) -> None: ...
global___ResponseEcho = ResponseEcho

class ResponseFlush(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___ResponseFlush = ResponseFlush

class ResponseInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    APP_VERSION_FIELD_NUMBER: builtins.int
    LAST_BLOCK_HEIGHT_FIELD_NUMBER: builtins.int
    LAST_BLOCK_APP_HASH_FIELD_NUMBER: builtins.int
    data: typing.Text = ...
    version: typing.Text = ...
    app_version: builtins.int = ...
    last_block_height: builtins.int = ...
    last_block_app_hash: builtins.bytes = ...

    def __init__(self,
        *,
        data : typing.Text = ...,
        version : typing.Text = ...,
        app_version : builtins.int = ...,
        last_block_height : builtins.int = ...,
        last_block_app_hash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_version",b"app_version",u"data",b"data",u"last_block_app_hash",b"last_block_app_hash",u"last_block_height",b"last_block_height",u"version",b"version"]) -> None: ...
global___ResponseInfo = ResponseInfo

class ResponseSetOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CODE_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    code: builtins.int = ...
    log: typing.Text = ...
    info: typing.Text = ...

    def __init__(self,
        *,
        code : builtins.int = ...,
        log : typing.Text = ...,
        info : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"info",b"info",u"log",b"log"]) -> None: ...
global___ResponseSetOption = ResponseSetOption

class ResponseInitChain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONSENSUS_PARAMS_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    APP_HASH_FIELD_NUMBER: builtins.int
    app_hash: builtins.bytes = ...

    @property
    def consensus_params(self) -> global___ConsensusParams: ...

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorUpdate]: ...

    def __init__(self,
        *,
        consensus_params : typing.Optional[global___ConsensusParams] = ...,
        validators : typing.Optional[typing.Iterable[global___ValidatorUpdate]] = ...,
        app_hash : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_params",b"consensus_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app_hash",b"app_hash",u"consensus_params",b"consensus_params",u"validators",b"validators"]) -> None: ...
global___ResponseInitChain = ResponseInitChain

class ResponseQuery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CODE_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    PROOF_OPS_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    CODESPACE_FIELD_NUMBER: builtins.int
    code: builtins.int = ...
    log: typing.Text = ...
    info: typing.Text = ...
    index: builtins.int = ...
    key: builtins.bytes = ...
    value: builtins.bytes = ...
    height: builtins.int = ...
    codespace: typing.Text = ...

    @property
    def proof_ops(self) -> tendermint.crypto.proof_pb2.ProofOps: ...

    def __init__(self,
        *,
        code : builtins.int = ...,
        log : typing.Text = ...,
        info : typing.Text = ...,
        index : builtins.int = ...,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        proof_ops : typing.Optional[tendermint.crypto.proof_pb2.ProofOps] = ...,
        height : builtins.int = ...,
        codespace : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_ops",b"proof_ops"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"codespace",b"codespace",u"height",b"height",u"index",b"index",u"info",b"info",u"key",b"key",u"log",b"log",u"proof_ops",b"proof_ops",u"value",b"value"]) -> None: ...
global___ResponseQuery = ResponseQuery

class ResponseBeginBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EVENTS_FIELD_NUMBER: builtins.int

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...

    def __init__(self,
        *,
        events : typing.Optional[typing.Iterable[global___Event]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"events",b"events"]) -> None: ...
global___ResponseBeginBlock = ResponseBeginBlock

class ResponseCheckTx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    GAS_WANTED_FIELD_NUMBER: builtins.int
    GAS_USED_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    CODESPACE_FIELD_NUMBER: builtins.int
    code: builtins.int = ...
    data: builtins.bytes = ...
    log: typing.Text = ...
    info: typing.Text = ...
    gas_wanted: builtins.int = ...
    gas_used: builtins.int = ...
    codespace: typing.Text = ...

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...

    def __init__(self,
        *,
        code : builtins.int = ...,
        data : builtins.bytes = ...,
        log : typing.Text = ...,
        info : typing.Text = ...,
        gas_wanted : builtins.int = ...,
        gas_used : builtins.int = ...,
        events : typing.Optional[typing.Iterable[global___Event]] = ...,
        codespace : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"codespace",b"codespace",u"data",b"data",u"events",b"events",u"gas_used",b"gas_used",u"gas_wanted",b"gas_wanted",u"info",b"info",u"log",b"log"]) -> None: ...
global___ResponseCheckTx = ResponseCheckTx

class ResponseDeliverTx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    LOG_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    GAS_WANTED_FIELD_NUMBER: builtins.int
    GAS_USED_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    CODESPACE_FIELD_NUMBER: builtins.int
    code: builtins.int = ...
    data: builtins.bytes = ...
    log: typing.Text = ...
    info: typing.Text = ...
    gas_wanted: builtins.int = ...
    gas_used: builtins.int = ...
    codespace: typing.Text = ...

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...

    def __init__(self,
        *,
        code : builtins.int = ...,
        data : builtins.bytes = ...,
        log : typing.Text = ...,
        info : typing.Text = ...,
        gas_wanted : builtins.int = ...,
        gas_used : builtins.int = ...,
        events : typing.Optional[typing.Iterable[global___Event]] = ...,
        codespace : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"code",b"code",u"codespace",b"codespace",u"data",b"data",u"events",b"events",u"gas_used",b"gas_used",u"gas_wanted",b"gas_wanted",u"info",b"info",u"log",b"log"]) -> None: ...
global___ResponseDeliverTx = ResponseDeliverTx

class ResponseEndBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_UPDATES_FIELD_NUMBER: builtins.int
    CONSENSUS_PARAM_UPDATES_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int

    @property
    def validator_updates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorUpdate]: ...

    @property
    def consensus_param_updates(self) -> global___ConsensusParams: ...

    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Event]: ...

    def __init__(self,
        *,
        validator_updates : typing.Optional[typing.Iterable[global___ValidatorUpdate]] = ...,
        consensus_param_updates : typing.Optional[global___ConsensusParams] = ...,
        events : typing.Optional[typing.Iterable[global___Event]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_param_updates",b"consensus_param_updates"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"consensus_param_updates",b"consensus_param_updates",u"events",b"events",u"validator_updates",b"validator_updates"]) -> None: ...
global___ResponseEndBlock = ResponseEndBlock

class ResponseCommit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    RETAIN_HEIGHT_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    retain_height: builtins.int = ...

    def __init__(self,
        *,
        data : builtins.bytes = ...,
        retain_height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"retain_height",b"retain_height"]) -> None: ...
global___ResponseCommit = ResponseCommit

class ResponseListSnapshots(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SNAPSHOTS_FIELD_NUMBER: builtins.int

    @property
    def snapshots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Snapshot]: ...

    def __init__(self,
        *,
        snapshots : typing.Optional[typing.Iterable[global___Snapshot]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"snapshots",b"snapshots"]) -> None: ...
global___ResponseListSnapshots = ResponseListSnapshots

class ResponseOfferSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Result(metaclass=_Result):
        V = typing.NewType('V', builtins.int)

    UNKNOWN = ResponseOfferSnapshot.Result.V(0)
    ACCEPT = ResponseOfferSnapshot.Result.V(1)
    ABORT = ResponseOfferSnapshot.Result.V(2)
    REJECT = ResponseOfferSnapshot.Result.V(3)
    REJECT_FORMAT = ResponseOfferSnapshot.Result.V(4)
    REJECT_SENDER = ResponseOfferSnapshot.Result.V(5)

    class _Result(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Result.V], builtins.type):  # type: ignore
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNKNOWN = ResponseOfferSnapshot.Result.V(0)
        ACCEPT = ResponseOfferSnapshot.Result.V(1)
        ABORT = ResponseOfferSnapshot.Result.V(2)
        REJECT = ResponseOfferSnapshot.Result.V(3)
        REJECT_FORMAT = ResponseOfferSnapshot.Result.V(4)
        REJECT_SENDER = ResponseOfferSnapshot.Result.V(5)

    RESULT_FIELD_NUMBER: builtins.int
    result: global___ResponseOfferSnapshot.Result.V = ...

    def __init__(self,
        *,
        result : global___ResponseOfferSnapshot.Result.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"result",b"result"]) -> None: ...
global___ResponseOfferSnapshot = ResponseOfferSnapshot

class ResponseLoadSnapshotChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHUNK_FIELD_NUMBER: builtins.int
    chunk: builtins.bytes = ...

    def __init__(self,
        *,
        chunk : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunk",b"chunk"]) -> None: ...
global___ResponseLoadSnapshotChunk = ResponseLoadSnapshotChunk

class ResponseApplySnapshotChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Result(metaclass=_Result):
        V = typing.NewType('V', builtins.int)

    UNKNOWN = ResponseApplySnapshotChunk.Result.V(0)
    ACCEPT = ResponseApplySnapshotChunk.Result.V(1)
    ABORT = ResponseApplySnapshotChunk.Result.V(2)
    RETRY = ResponseApplySnapshotChunk.Result.V(3)
    RETRY_SNAPSHOT = ResponseApplySnapshotChunk.Result.V(4)
    REJECT_SNAPSHOT = ResponseApplySnapshotChunk.Result.V(5)

    class _Result(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Result.V], builtins.type):  # type: ignore
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNKNOWN = ResponseApplySnapshotChunk.Result.V(0)
        ACCEPT = ResponseApplySnapshotChunk.Result.V(1)
        ABORT = ResponseApplySnapshotChunk.Result.V(2)
        RETRY = ResponseApplySnapshotChunk.Result.V(3)
        RETRY_SNAPSHOT = ResponseApplySnapshotChunk.Result.V(4)
        REJECT_SNAPSHOT = ResponseApplySnapshotChunk.Result.V(5)

    RESULT_FIELD_NUMBER: builtins.int
    REFETCH_CHUNKS_FIELD_NUMBER: builtins.int
    REJECT_SENDERS_FIELD_NUMBER: builtins.int
    result: global___ResponseApplySnapshotChunk.Result.V = ...

    @property
    def refetch_chunks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    @property
    def reject_senders(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        result : global___ResponseApplySnapshotChunk.Result.V = ...,
        refetch_chunks : typing.Optional[typing.Iterable[builtins.int]] = ...,
        reject_senders : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"refetch_chunks",b"refetch_chunks",u"reject_senders",b"reject_senders",u"result",b"result"]) -> None: ...
global___ResponseApplySnapshotChunk = ResponseApplySnapshotChunk

class ConsensusParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int

    @property
    def block(self) -> global___BlockParams: ...

    @property
    def evidence(self) -> tendermint.types.params_pb2.EvidenceParams: ...

    @property
    def validator(self) -> tendermint.types.params_pb2.ValidatorParams: ...

    @property
    def version(self) -> tendermint.types.params_pb2.VersionParams: ...

    def __init__(self,
        *,
        block : typing.Optional[global___BlockParams] = ...,
        evidence : typing.Optional[tendermint.types.params_pb2.EvidenceParams] = ...,
        validator : typing.Optional[tendermint.types.params_pb2.ValidatorParams] = ...,
        version : typing.Optional[tendermint.types.params_pb2.VersionParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"block",b"block",u"evidence",b"evidence",u"validator",b"validator",u"version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"block",b"block",u"evidence",b"evidence",u"validator",b"validator",u"version",b"version"]) -> None: ...
global___ConsensusParams = ConsensusParams

class BlockParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_BYTES_FIELD_NUMBER: builtins.int
    MAX_GAS_FIELD_NUMBER: builtins.int
    max_bytes: builtins.int = ...
    max_gas: builtins.int = ...

    def __init__(self,
        *,
        max_bytes : builtins.int = ...,
        max_gas : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_bytes",b"max_bytes",u"max_gas",b"max_gas"]) -> None: ...
global___BlockParams = BlockParams

class LastCommitInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ROUND_FIELD_NUMBER: builtins.int
    VOTES_FIELD_NUMBER: builtins.int
    round: builtins.int = ...

    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VoteInfo]: ...

    def __init__(self,
        *,
        round : builtins.int = ...,
        votes : typing.Optional[typing.Iterable[global___VoteInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"round",b"round",u"votes",b"votes"]) -> None: ...
global___LastCommitInfo = LastCommitInfo

class Event(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    ATTRIBUTES_FIELD_NUMBER: builtins.int
    type: typing.Text = ...

    @property
    def attributes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventAttribute]: ...

    def __init__(self,
        *,
        type : typing.Text = ...,
        attributes : typing.Optional[typing.Iterable[global___EventAttribute]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"attributes",b"attributes",u"type",b"type"]) -> None: ...
global___Event = Event

class EventAttribute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...
    value: builtins.bytes = ...
    index: builtins.bool = ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        value : builtins.bytes = ...,
        index : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"index",b"index",u"key",b"key",u"value",b"value"]) -> None: ...
global___EventAttribute = EventAttribute

class TxResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TX_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    index: builtins.int = ...
    tx: builtins.bytes = ...

    @property
    def result(self) -> global___ResponseDeliverTx: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        index : builtins.int = ...,
        tx : builtins.bytes = ...,
        result : typing.Optional[global___ResponseDeliverTx] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"result",b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"index",b"index",u"result",b"result",u"tx",b"tx"]) -> None: ...
global___TxResult = TxResult

class Validator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    address: builtins.bytes = ...
    power: builtins.int = ...

    def __init__(self,
        *,
        address : builtins.bytes = ...,
        power : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"power",b"power"]) -> None: ...
global___Validator = Validator

class ValidatorUpdate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUB_KEY_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    power: builtins.int = ...

    @property
    def pub_key(self) -> tendermint.crypto.keys_pb2.PublicKey: ...

    def __init__(self,
        *,
        pub_key : typing.Optional[tendermint.crypto.keys_pb2.PublicKey] = ...,
        power : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"power",b"power",u"pub_key",b"pub_key"]) -> None: ...
global___ValidatorUpdate = ValidatorUpdate

class VoteInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    SIGNED_LAST_BLOCK_FIELD_NUMBER: builtins.int
    signed_last_block: builtins.bool = ...

    @property
    def validator(self) -> global___Validator: ...

    def __init__(self,
        *,
        validator : typing.Optional[global___Validator] = ...,
        signed_last_block : builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"validator",b"validator"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signed_last_block",b"signed_last_block",u"validator",b"validator"]) -> None: ...
global___VoteInfo = VoteInfo

class Evidence(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    type: global___EvidenceType.V = ...
    height: builtins.int = ...
    total_voting_power: builtins.int = ...

    @property
    def validator(self) -> global___Validator: ...

    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        type : global___EvidenceType.V = ...,
        validator : typing.Optional[global___Validator] = ...,
        height : builtins.int = ...,
        time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        total_voting_power : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"time",b"time",u"validator",b"validator"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"time",b"time",u"total_voting_power",b"total_voting_power",u"type",b"type",u"validator",b"validator"]) -> None: ...
global___Evidence = Evidence

class Snapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    format: builtins.int = ...
    chunks: builtins.int = ...
    hash: builtins.bytes = ...
    metadata: builtins.bytes = ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        format : builtins.int = ...,
        chunks : builtins.int = ...,
        hash : builtins.bytes = ...,
        metadata : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunks",b"chunks",u"format",b"format",u"hash",b"hash",u"height",b"height",u"metadata",b"metadata"]) -> None: ...
global___Snapshot = Snapshot



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.distribution.v1beta1.distribution_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DelegatorWithdrawInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...
    withdraw_address: typing.Text = ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        withdraw_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_address",b"delegator_address",u"withdraw_address",b"withdraw_address"]) -> None: ...
global___DelegatorWithdrawInfo = DelegatorWithdrawInfo

class ValidatorOutstandingRewardsRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    OUTSTANDING_REWARDS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    @property
    def outstanding_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        outstanding_rewards : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"outstanding_rewards",b"outstanding_rewards",u"validator_address",b"validator_address"]) -> None: ...
global___ValidatorOutstandingRewardsRecord = ValidatorOutstandingRewardsRecord

class ValidatorAccumulatedCommissionRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    ACCUMULATED_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    @property
    def accumulated(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        accumulated : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"accumulated",b"accumulated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"accumulated",b"accumulated",u"validator_address",b"validator_address"]) -> None: ...
global___ValidatorAccumulatedCommissionRecord = ValidatorAccumulatedCommissionRecord

class ValidatorHistoricalRewardsRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...
    period: builtins.int = ...

    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorHistoricalRewards: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        period : builtins.int = ...,
        rewards : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorHistoricalRewards] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"period",b"period",u"rewards",b"rewards",u"validator_address",b"validator_address"]) -> None: ...
global___ValidatorHistoricalRewardsRecord = ValidatorHistoricalRewardsRecord

class ValidatorCurrentRewardsRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorCurrentRewards: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        rewards : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorCurrentRewards] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards",u"validator_address",b"validator_address"]) -> None: ...
global___ValidatorCurrentRewardsRecord = ValidatorCurrentRewardsRecord

class DelegatorStartingInfoRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    STARTING_INFO_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...
    validator_address: typing.Text = ...

    @property
    def starting_info(self) -> cosmos.distribution.v1beta1.distribution_pb2.DelegatorStartingInfo: ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        validator_address : typing.Text = ...,
        starting_info : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.DelegatorStartingInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"starting_info",b"starting_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_address",b"delegator_address",u"starting_info",b"starting_info",u"validator_address",b"validator_address"]) -> None: ...
global___DelegatorStartingInfoRecord = DelegatorStartingInfoRecord

class ValidatorSlashEventRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    VALIDATOR_SLASH_EVENT_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...
    height: builtins.int = ...
    period: builtins.int = ...

    @property
    def validator_slash_event(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        height : builtins.int = ...,
        period : builtins.int = ...,
        validator_slash_event : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"validator_slash_event",b"validator_slash_event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"period",b"period",u"validator_address",b"validator_address",u"validator_slash_event",b"validator_slash_event"]) -> None: ...
global___ValidatorSlashEventRecord = ValidatorSlashEventRecord

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int
    FEE_POOL_FIELD_NUMBER: builtins.int
    DELEGATOR_WITHDRAW_INFOS_FIELD_NUMBER: builtins.int
    PREVIOUS_PROPOSER_FIELD_NUMBER: builtins.int
    OUTSTANDING_REWARDS_FIELD_NUMBER: builtins.int
    VALIDATOR_ACCUMULATED_COMMISSIONS_FIELD_NUMBER: builtins.int
    VALIDATOR_HISTORICAL_REWARDS_FIELD_NUMBER: builtins.int
    VALIDATOR_CURRENT_REWARDS_FIELD_NUMBER: builtins.int
    DELEGATOR_STARTING_INFOS_FIELD_NUMBER: builtins.int
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: builtins.int
    previous_proposer: typing.Text = ...

    @property
    def params(self) -> cosmos.distribution.v1beta1.distribution_pb2.Params: ...

    @property
    def fee_pool(self) -> cosmos.distribution.v1beta1.distribution_pb2.FeePool: ...

    @property
    def delegator_withdraw_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DelegatorWithdrawInfo]: ...

    @property
    def outstanding_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorOutstandingRewardsRecord]: ...

    @property
    def validator_accumulated_commissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorAccumulatedCommissionRecord]: ...

    @property
    def validator_historical_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorHistoricalRewardsRecord]: ...

    @property
    def validator_current_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorCurrentRewardsRecord]: ...

    @property
    def delegator_starting_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DelegatorStartingInfoRecord]: ...

    @property
    def validator_slash_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorSlashEventRecord]: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.Params] = ...,
        fee_pool : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.FeePool] = ...,
        delegator_withdraw_infos : typing.Optional[typing.Iterable[global___DelegatorWithdrawInfo]] = ...,
        previous_proposer : typing.Text = ...,
        outstanding_rewards : typing.Optional[typing.Iterable[global___ValidatorOutstandingRewardsRecord]] = ...,
        validator_accumulated_commissions : typing.Optional[typing.Iterable[global___ValidatorAccumulatedCommissionRecord]] = ...,
        validator_historical_rewards : typing.Optional[typing.Iterable[global___ValidatorHistoricalRewardsRecord]] = ...,
        validator_current_rewards : typing.Optional[typing.Iterable[global___ValidatorCurrentRewardsRecord]] = ...,
        delegator_starting_infos : typing.Optional[typing.Iterable[global___DelegatorStartingInfoRecord]] = ...,
        validator_slash_events : typing.Optional[typing.Iterable[global___ValidatorSlashEventRecord]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"fee_pool",b"fee_pool",u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_starting_infos",b"delegator_starting_infos",u"delegator_withdraw_infos",b"delegator_withdraw_infos",u"fee_pool",b"fee_pool",u"outstanding_rewards",b"outstanding_rewards",u"params",b"params",u"previous_proposer",b"previous_proposer",u"validator_accumulated_commissions",b"validator_accumulated_commissions",u"validator_current_rewards",b"validator_current_rewards",u"validator_historical_rewards",b"validator_historical_rewards",u"validator_slash_events",b"validator_slash_events"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ClientState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"height",b"height"]) -> None: ...
global___ClientState = ClientState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .reflection_pb2 import *
class ReflectionServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ListAllInterfaces:grpc.UnaryUnaryMultiCallable[
        global___ListAllInterfacesRequest,
        global___ListAllInterfacesResponse] = ...

    ListImplementations:grpc.UnaryUnaryMultiCallable[
        global___ListImplementationsRequest,
        global___ListImplementationsResponse] = ...


class ReflectionServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListAllInterfaces(self,
        request: global___ListAllInterfacesRequest,
        context: grpc.ServicerContext,
    ) -> global___ListAllInterfacesResponse: ...

    @abc.abstractmethod
    def ListImplementations(self,
        request: global___ListImplementationsRequest,
        context: grpc.ServicerContext,
    ) -> global___ListImplementationsResponse: ...


def add_ReflectionServiceServicer_to_server(servicer: ReflectionServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ResolveStatus(metaclass=_ResolveStatus):
    V = typing.NewType('V', builtins.int)

global___ResolveStatus = ResolveStatus

RESOLVE_STATUS_OPEN_UNSPECIFIED = ResolveStatus.V(0)
RESOLVE_STATUS_SUCCESS = ResolveStatus.V(1)
RESOLVE_STATUS_FAILURE = ResolveStatus.V(2)
RESOLVE_STATUS_EXPIRED = ResolveStatus.V(3)

class _ResolveStatus(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ResolveStatus.V], builtins.type):  # type: ignore
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    RESOLVE_STATUS_OPEN_UNSPECIFIED = ResolveStatus.V(0)
    RESOLVE_STATUS_SUCCESS = ResolveStatus.V(1)
    RESOLVE_STATUS_FAILURE = ResolveStatus.V(2)
    RESOLVE_STATUS_EXPIRED = ResolveStatus.V(3)

class DataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OWNER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    TREASURY_FIELD_NUMBER: builtins.int
    FEE_FIELD_NUMBER: builtins.int
    owner: typing.Text = ...
    name: typing.Text = ...
    description: typing.Text = ...
    filename: typing.Text = ...
    treasury: typing.Text = ...

    @property
    def fee(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        owner : typing.Text = ...,
        name : typing.Text = ...,
        description : typing.Text = ...,
        filename : typing.Text = ...,
        treasury : typing.Text = ...,
        fee : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"fee",b"fee",u"filename",b"filename",u"name",b"name",u"owner",b"owner",u"treasury",b"treasury"]) -> None: ...
global___DataSource = DataSource

class OracleScript(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OWNER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_CODE_URL_FIELD_NUMBER: builtins.int
    owner: typing.Text = ...
    name: typing.Text = ...
    description: typing.Text = ...
    filename: typing.Text = ...
    schema: typing.Text = ...
    source_code_url: typing.Text = ...

    def __init__(self,
        *,
        owner : typing.Text = ...,
        name : typing.Text = ...,
        description : typing.Text = ...,
        filename : typing.Text = ...,
        schema : typing.Text = ...,
        source_code_url : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"filename",b"filename",u"name",b"name",u"owner",b"owner",u"schema",b"schema",u"source_code_url",b"source_code_url"]) -> None: ...
global___OracleScript = OracleScript

class RawRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    DATA_SOURCE_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    external_id: builtins.int = ...
    data_source_id: builtins.int = ...
    calldata: builtins.bytes = ...

    def __init__(self,
        *,
        external_id : builtins.int = ...,
        data_source_id : builtins.int = ...,
        calldata : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"calldata",b"calldata",u"data_source_id",b"data_source_id",u"external_id",b"external_id"]) -> None: ...
global___RawRequest = RawRequest

class RawReport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    external_id: builtins.int = ...
    exit_code: builtins.int = ...
    data: builtins.bytes = ...

    def __init__(self,
        *,
        external_id : builtins.int = ...,
        exit_code : builtins.int = ...,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"exit_code",b"exit_code",u"external_id",b"external_id"]) -> None: ...
global___RawReport = RawReport

class Request(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    REQUESTED_VALIDATORS_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    REQUEST_HEIGHT_FIELD_NUMBER: builtins.int
    REQUEST_TIME_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    RAW_REQUESTS_FIELD_NUMBER: builtins.int
    IBC_CHANNEL_FIELD_NUMBER: builtins.int
    EXECUTE_GAS_FIELD_NUMBER: builtins.int
    oracle_script_id: builtins.int = ...
    calldata: builtins.bytes = ...

    @property
    def requested_validators(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    min_count: builtins.int = ...
    request_height: builtins.int = ...
    request_time: builtins.int = ...
    client_id: typing.Text = ...
    execute_gas: builtins.int = ...

    @property
    def raw_requests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RawRequest]: ...

    @property
    def ibc_channel(self) -> global___IBCChannel: ...

    def __init__(self,
        *,
        oracle_script_id : builtins.int = ...,
        calldata : builtins.bytes = ...,
        requested_validators : typing.Optional[typing.Iterable[typing.Text]] = ...,
        min_count : builtins.int = ...,
        request_height : builtins.int = ...,
        request_time : builtins.int = ...,
        client_id : typing.Text = ...,
        raw_requests : typing.Optional[typing.Iterable[global___RawRequest]] = ...,
        ibc_channel : typing.Optional[global___IBCChannel] = ...,
        execute_gas : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"ibc_channel",b"ibc_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"calldata",b"calldata",u"client_id",b"client_id",u"execute_gas",b"execute_gas",u"ibc_channel",b"ibc_channel",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id",u"raw_requests",b"raw_requests",u"request_height",b"request_height",u"request_time",b"request_time",u"requested_validators",b"requested_validators"]) -> None: ...
global___Request = Request

class Report(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    IN_BEFORE_RESOLVE_FIELD_NUMBER: builtins.int
    RAW_REPORTS_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...
    in_before_resolve: builtins.bool = ...

    @property
    def raw_reports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RawReport]: ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        in_before_resolve : builtins.bool = ...,
        raw_reports : typing.Optional[typing.Iterable[global___RawReport]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"in_before_resolve",b"in_before_resolve",u"raw_reports",b"raw_reports",u"validator",b"validator"]) -> None: ...
global___Report = Report

class OracleRequestPacketData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    FEE_LIMIT_FIELD_NUMBER: builtins.int
    REQUEST_KEY_FIELD_NUMBER: builtins.int
    PREPARE_GAS_FIELD_NUMBER: builtins.int
    EXECUTE_GAS_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    oracle_script_id: builtins.int = ...
    calldata: builtins.bytes = ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...
    request_key: typing.Text = ...
    prepare_gas: builtins.int = ...
    execute_gas: builtins.int = ...

    @property
    def fee_limit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        oracle_script_id : builtins.int = ...,
        calldata : builtins.bytes = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        fee_limit : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        request_key : typing.Text = ...,
        prepare_gas : builtins.int = ...,
        execute_gas : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ask_count",b"ask_count",u"calldata",b"calldata",u"client_id",b"client_id",u"execute_gas",b"execute_gas",u"fee_limit",b"fee_limit",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id",u"prepare_gas",b"prepare_gas",u"request_key",b"request_key"]) -> None: ...
global___OracleRequestPacketData = OracleRequestPacketData

class OracleRequestPacketAcknowledgement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.int = ...

    def __init__(self,
        *,
        request_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_id",b"request_id"]) -> None: ...
global___OracleRequestPacketAcknowledgement = OracleRequestPacketAcknowledgement

class OracleResponsePacketData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    ANS_COUNT_FIELD_NUMBER: builtins.int
    REQUEST_TIME_FIELD_NUMBER: builtins.int
    RESOLVE_TIME_FIELD_NUMBER: builtins.int
    RESOLVE_STATUS_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    request_id: builtins.int = ...
    ans_count: builtins.int = ...
    request_time: builtins.int = ...
    resolve_time: builtins.int = ...
    resolve_status: global___ResolveStatus.V = ...
    result: builtins.bytes = ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        request_id : builtins.int = ...,
        ans_count : builtins.int = ...,
        request_time : builtins.int = ...,
        resolve_time : builtins.int = ...,
        resolve_status : global___ResolveStatus.V = ...,
        result : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ans_count",b"ans_count",u"client_id",b"client_id",u"request_id",b"request_id",u"request_time",b"request_time",u"resolve_status",b"resolve_status",u"resolve_time",b"resolve_time",u"result",b"result"]) -> None: ...
global___OracleResponsePacketData = OracleResponsePacketData

class Result(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    ORACLE_SCRIPT_ID_FIELD_NUMBER: builtins.int
    CALLDATA_FIELD_NUMBER: builtins.int
    ASK_COUNT_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    ANS_COUNT_FIELD_NUMBER: builtins.int
    REQUEST_TIME_FIELD_NUMBER: builtins.int
    RESOLVE_TIME_FIELD_NUMBER: builtins.int
    RESOLVE_STATUS_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    oracle_script_id: builtins.int = ...
    calldata: builtins.bytes = ...
    ask_count: builtins.int = ...
    min_count: builtins.int = ...
    request_id: builtins.int = ...
    ans_count: builtins.int = ...
    request_time: builtins.int = ...
    resolve_time: builtins.int = ...
    resolve_status: global___ResolveStatus.V = ...
    result: builtins.bytes = ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        oracle_script_id : builtins.int = ...,
        calldata : builtins.bytes = ...,
        ask_count : builtins.int = ...,
        min_count : builtins.int = ...,
        request_id : builtins.int = ...,
        ans_count : builtins.int = ...,
        request_time : builtins.int = ...,
        resolve_time : builtins.int = ...,
        resolve_status : global___ResolveStatus.V = ...,
        result : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ans_count",b"ans_count",u"ask_count",b"ask_count",u"calldata",b"calldata",u"client_id",b"client_id",u"min_count",b"min_count",u"oracle_script_id",b"oracle_script_id",u"request_id",b"request_id",u"request_time",b"request_time",u"resolve_status",b"resolve_status",u"resolve_time",b"resolve_time",u"result",b"result"]) -> None: ...
global___Result = Result

class ValidatorStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IS_ACTIVE_FIELD_NUMBER: builtins.int
    SINCE_FIELD_NUMBER: builtins.int
    is_active: builtins.bool = ...

    @property
    def since(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        is_active : builtins.bool = ...,
        since : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"since",b"since"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"is_active",b"is_active",u"since",b"since"]) -> None: ...
global___ValidatorStatus = ValidatorStatus

class ActiveValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    power: builtins.int = ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        power : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"power",b"power"]) -> None: ...
global___ActiveValidator = ActiveValidator

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_RAW_REQUEST_COUNT_FIELD_NUMBER: builtins.int
    MAX_ASK_COUNT_FIELD_NUMBER: builtins.int
    EXPIRATION_BLOCK_COUNT_FIELD_NUMBER: builtins.int
    BASE_OWASM_GAS_FIELD_NUMBER: builtins.int
    PER_VALIDATOR_REQUEST_GAS_FIELD_NUMBER: builtins.int
    SAMPLING_TRY_COUNT_FIELD_NUMBER: builtins.int
    ORACLE_REWARD_PERCENTAGE_FIELD_NUMBER: builtins.int
    INACTIVE_PENALTY_DURATION_FIELD_NUMBER: builtins.int
    IBC_REQUEST_ENABLED_FIELD_NUMBER: builtins.int
    max_raw_request_count: builtins.int = ...
    max_ask_count: builtins.int = ...
    expiration_block_count: builtins.int = ...
    base_owasm_gas: builtins.int = ...
    per_validator_request_gas: builtins.int = ...
    sampling_try_count: builtins.int = ...
    oracle_reward_percentage: builtins.int = ...
    inactive_penalty_duration: builtins.int = ...
    ibc_request_enabled: builtins.bool = ...

    def __init__(self,
        *,
        max_raw_request_count : builtins.int = ...,
        max_ask_count : builtins.int = ...,
        expiration_block_count : builtins.int = ...,
        base_owasm_gas : builtins.int = ...,
        per_validator_request_gas : builtins.int = ...,
        sampling_try_count : builtins.int = ...,
        oracle_reward_percentage : builtins.int = ...,
        inactive_penalty_duration : builtins.int = ...,
        ibc_request_enabled : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_owasm_gas",b"base_owasm_gas",u"expiration_block_count",b"expiration_block_count",u"ibc_request_enabled",b"ibc_request_enabled",u"inactive_penalty_duration",b"inactive_penalty_duration",u"max_ask_count",b"max_ask_count",u"max_raw_request_count",b"max_raw_request_count",u"oracle_reward_percentage",b"oracle_reward_percentage",u"per_validator_request_gas",b"per_validator_request_gas",u"sampling_try_count",b"sampling_try_count"]) -> None: ...
global___Params = Params

class PendingResolveList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REQUEST_IDS_FIELD_NUMBER: builtins.int

    @property
    def request_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    def __init__(self,
        *,
        request_ids : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_ids",b"request_ids"]) -> None: ...
global___PendingResolveList = PendingResolveList

class IBCChannel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id"]) -> None: ...
global___IBCChannel = IBCChannel

class ReportersPerValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_FIELD_NUMBER: builtins.int
    REPORTERS_FIELD_NUMBER: builtins.int
    validator: typing.Text = ...

    @property
    def reporters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        validator : typing.Text = ...,
        reporters : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"reporters",b"reporters",u"validator",b"validator"]) -> None: ...
global___ReportersPerValidator = ReportersPerValidator

class RequestVerification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHAIN_ID_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    chain_id: typing.Text = ...
    validator: typing.Text = ...
    request_id: builtins.int = ...
    external_id: builtins.int = ...

    def __init__(self,
        *,
        chain_id : typing.Text = ...,
        validator : typing.Text = ...,
        request_id : builtins.int = ...,
        external_id : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"external_id",b"external_id",u"request_id",b"request_id",u"validator",b"validator"]) -> None: ...
global___RequestVerification = RequestVerification

class PriceResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SYMBOL_FIELD_NUMBER: builtins.int
    MULTIPLIER_FIELD_NUMBER: builtins.int
    PX_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    RESOLVE_TIME_FIELD_NUMBER: builtins.int
    symbol: typing.Text = ...
    multiplier: builtins.int = ...
    px: builtins.int = ...
    request_id: builtins.int = ...
    resolve_time: builtins.int = ...

    def __init__(self,
        *,
        symbol : typing.Text = ...,
        multiplier : builtins.int = ...,
        px : builtins.int = ...,
        request_id : builtins.int = ...,
        resolve_time : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"multiplier",b"multiplier",u"px",b"px",u"request_id",b"request_id",u"resolve_time",b"resolve_time",u"symbol",b"symbol"]) -> None: ...
global___PriceResult = PriceResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.mint.v1beta1.mint_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MINTER_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def minter(self) -> cosmos.mint.v1beta1.mint_pb2.Minter: ...

    @property
    def params(self) -> cosmos.mint.v1beta1.mint_pb2.Params: ...

    def __init__(self,
        *,
        minter : typing.Optional[cosmos.mint.v1beta1.mint_pb2.Minter] = ...,
        params : typing.Optional[cosmos.mint.v1beta1.mint_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"minter",b"minter",u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"minter",b"minter",u"params",b"params"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.mint.v1beta1.mint_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> cosmos.mint.v1beta1.mint_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.mint.v1beta1.mint_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryInflationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryInflationRequest = QueryInflationRequest

class QueryInflationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INFLATION_FIELD_NUMBER: builtins.int
    inflation: builtins.bytes = ...

    def __init__(self,
        *,
        inflation : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"inflation",b"inflation"]) -> None: ...
global___QueryInflationResponse = QueryInflationResponse

class QueryAnnualProvisionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryAnnualProvisionsRequest = QueryAnnualProvisionsRequest

class QueryAnnualProvisionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ANNUAL_PROVISIONS_FIELD_NUMBER: builtins.int
    annual_provisions: builtins.bytes = ...

    def __init__(self,
        *,
        annual_provisions : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"annual_provisions",b"annual_provisions"]) -> None: ...
global___QueryAnnualProvisionsResponse = QueryAnnualProvisionsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BaseAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    ACCOUNT_NUMBER_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    account_number: builtins.int = ...
    sequence: builtins.int = ...

    @property
    def pub_key(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        pub_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        account_number : builtins.int = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pub_key",b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"account_number",b"account_number",u"address",b"address",u"pub_key",b"pub_key",u"sequence",b"sequence"]) -> None: ...
global___BaseAccount = BaseAccount

class ModuleAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BASE_ACCOUNT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    @property
    def base_account(self) -> global___BaseAccount: ...

    def __init__(self,
        *,
        base_account : typing.Optional[global___BaseAccount] = ...,
        name : typing.Text = ...,
        permissions : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"base_account",b"base_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_account",b"base_account",u"name",b"name",u"permissions",b"permissions"]) -> None: ...
global___ModuleAccount = ModuleAccount

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MAX_MEMO_CHARACTERS_FIELD_NUMBER: builtins.int
    TX_SIG_LIMIT_FIELD_NUMBER: builtins.int
    TX_SIZE_COST_PER_BYTE_FIELD_NUMBER: builtins.int
    SIG_VERIFY_COST_ED25519_FIELD_NUMBER: builtins.int
    SIG_VERIFY_COST_SECP256K1_FIELD_NUMBER: builtins.int
    max_memo_characters: builtins.int = ...
    tx_sig_limit: builtins.int = ...
    tx_size_cost_per_byte: builtins.int = ...
    sig_verify_cost_ed25519: builtins.int = ...
    sig_verify_cost_secp256k1: builtins.int = ...

    def __init__(self,
        *,
        max_memo_characters : builtins.int = ...,
        tx_sig_limit : builtins.int = ...,
        tx_size_cost_per_byte : builtins.int = ...,
        sig_verify_cost_ed25519 : builtins.int = ...,
        sig_verify_cost_secp256k1 : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"max_memo_characters",b"max_memo_characters",u"sig_verify_cost_ed25519",b"sig_verify_cost_ed25519",u"sig_verify_cost_secp256k1",b"sig_verify_cost_secp256k1",u"tx_sig_limit",b"tx_sig_limit",u"tx_size_cost_per_byte",b"tx_size_cost_per_byte"]) -> None: ...
global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int
    BALANCES_FIELD_NUMBER: builtins.int
    SUPPLY_FIELD_NUMBER: builtins.int
    DENOM_METADATA_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> cosmos.bank.v1beta1.bank_pb2.Params: ...

    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Balance]: ...

    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    @property
    def denom_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Metadata]: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.bank.v1beta1.bank_pb2.Params] = ...,
        balances : typing.Optional[typing.Iterable[global___Balance]] = ...,
        supply : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        denom_metadata : typing.Optional[typing.Iterable[cosmos.bank.v1beta1.bank_pb2.Metadata]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"balances",b"balances",u"denom_metadata",b"denom_metadata",u"params",b"params",u"supply",b"supply"]) -> None: ...
global___GenesisState = GenesisState

class Balance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        coins : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"coins",b"coins"]) -> None: ...
global___Balance = Balance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.crypto.multisig.v1beta1.multisig_pb2
import cosmos.tx.signing.v1beta1.signing_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Tx(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BODY_FIELD_NUMBER: builtins.int
    AUTH_INFO_FIELD_NUMBER: builtins.int
    SIGNATURES_FIELD_NUMBER: builtins.int

    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    @property
    def body(self) -> global___TxBody: ...

    @property
    def auth_info(self) -> global___AuthInfo: ...

    def __init__(self,
        *,
        body : typing.Optional[global___TxBody] = ...,
        auth_info : typing.Optional[global___AuthInfo] = ...,
        signatures : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"auth_info",b"auth_info",u"body",b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth_info",b"auth_info",u"body",b"body",u"signatures",b"signatures"]) -> None: ...
global___Tx = Tx

class TxRaw(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BODY_BYTES_FIELD_NUMBER: builtins.int
    AUTH_INFO_BYTES_FIELD_NUMBER: builtins.int
    SIGNATURES_FIELD_NUMBER: builtins.int
    body_bytes: builtins.bytes = ...
    auth_info_bytes: builtins.bytes = ...

    @property
    def signatures(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        body_bytes : builtins.bytes = ...,
        auth_info_bytes : builtins.bytes = ...,
        signatures : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auth_info_bytes",b"auth_info_bytes",u"body_bytes",b"body_bytes",u"signatures",b"signatures"]) -> None: ...
global___TxRaw = TxRaw

class SignDoc(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BODY_BYTES_FIELD_NUMBER: builtins.int
    AUTH_INFO_BYTES_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_NUMBER_FIELD_NUMBER: builtins.int
    body_bytes: builtins.bytes = ...
    auth_info_bytes: builtins.bytes = ...
    chain_id: typing.Text = ...
    account_number: builtins.int = ...

    def __init__(self,
        *,
        body_bytes : builtins.bytes = ...,
        auth_info_bytes : builtins.bytes = ...,
        chain_id : typing.Text = ...,
        account_number : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"account_number",b"account_number",u"auth_info_bytes",b"auth_info_bytes",u"body_bytes",b"body_bytes",u"chain_id",b"chain_id"]) -> None: ...
global___SignDoc = SignDoc

class TxBody(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGES_FIELD_NUMBER: builtins.int
    MEMO_FIELD_NUMBER: builtins.int
    TIMEOUT_HEIGHT_FIELD_NUMBER: builtins.int
    EXTENSION_OPTIONS_FIELD_NUMBER: builtins.int
    NON_CRITICAL_EXTENSION_OPTIONS_FIELD_NUMBER: builtins.int
    memo: typing.Text = ...
    timeout_height: builtins.int = ...

    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...

    @property
    def extension_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...

    @property
    def non_critical_extension_options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]: ...

    def __init__(self,
        *,
        messages : typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        memo : typing.Text = ...,
        timeout_height : builtins.int = ...,
        extension_options : typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        non_critical_extension_options : typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"extension_options",b"extension_options",u"memo",b"memo",u"messages",b"messages",u"non_critical_extension_options",b"non_critical_extension_options",u"timeout_height",b"timeout_height"]) -> None: ...
global___TxBody = TxBody

class AuthInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNER_INFOS_FIELD_NUMBER: builtins.int
    FEE_FIELD_NUMBER: builtins.int

    @property
    def signer_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SignerInfo]: ...

    @property
    def fee(self) -> global___Fee: ...

    def __init__(self,
        *,
        signer_infos : typing.Optional[typing.Iterable[global___SignerInfo]] = ...,
        fee : typing.Optional[global___Fee] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"fee",b"fee"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"fee",b"fee",u"signer_infos",b"signer_infos"]) -> None: ...
global___AuthInfo = AuthInfo

class SignerInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    MODE_INFO_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    sequence: builtins.int = ...

    @property
    def public_key(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def mode_info(self) -> global___ModeInfo: ...

    def __init__(self,
        *,
        public_key : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        mode_info : typing.Optional[global___ModeInfo] = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"mode_info",b"mode_info",u"public_key",b"public_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"mode_info",b"mode_info",u"public_key",b"public_key",u"sequence",b"sequence"]) -> None: ...
global___SignerInfo = SignerInfo

class ModeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Single(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        MODE_FIELD_NUMBER: builtins.int
        mode: cosmos.tx.signing.v1beta1.signing_pb2.SignMode.V = ...

        def __init__(self,
            *,
            mode : cosmos.tx.signing.v1beta1.signing_pb2.SignMode.V = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"mode",b"mode"]) -> None: ...

    class Multi(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        BITARRAY_FIELD_NUMBER: builtins.int
        MODE_INFOS_FIELD_NUMBER: builtins.int

        @property
        def bitarray(self) -> cosmos.crypto.multisig.v1beta1.multisig_pb2.CompactBitArray: ...

        @property
        def mode_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModeInfo]: ...

        def __init__(self,
            *,
            bitarray : typing.Optional[cosmos.crypto.multisig.v1beta1.multisig_pb2.CompactBitArray] = ...,
            mode_infos : typing.Optional[typing.Iterable[global___ModeInfo]] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"bitarray",b"bitarray"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"bitarray",b"bitarray",u"mode_infos",b"mode_infos"]) -> None: ...

    SINGLE_FIELD_NUMBER: builtins.int
    MULTI_FIELD_NUMBER: builtins.int

    @property
    def single(self) -> global___ModeInfo.Single: ...

    @property
    def multi(self) -> global___ModeInfo.Multi: ...

    def __init__(self,
        *,
        single : typing.Optional[global___ModeInfo.Single] = ...,
        multi : typing.Optional[global___ModeInfo.Multi] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"multi",b"multi",u"single",b"single",u"sum",b"sum"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"multi",b"multi",u"single",b"single",u"sum",b"sum"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"sum",b"sum"]) -> typing.Optional[typing_extensions.Literal["single","multi"]]: ...
global___ModeInfo = ModeInfo

class Fee(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AMOUNT_FIELD_NUMBER: builtins.int
    GAS_LIMIT_FIELD_NUMBER: builtins.int
    PAYER_FIELD_NUMBER: builtins.int
    GRANTER_FIELD_NUMBER: builtins.int
    gas_limit: builtins.int = ...
    payer: typing.Text = ...
    granter: typing.Text = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        gas_limit : builtins.int = ...,
        payer : typing.Text = ...,
        granter : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"gas_limit",b"gas_limit",u"granter",b"granter",u"payer",b"payer"]) -> None: ...
global___Fee = Fee



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateClient:grpc.UnaryUnaryMultiCallable[
        global___MsgCreateClient,
        global___MsgCreateClientResponse] = ...

    UpdateClient:grpc.UnaryUnaryMultiCallable[
        global___MsgUpdateClient,
        global___MsgUpdateClientResponse] = ...

    UpgradeClient:grpc.UnaryUnaryMultiCallable[
        global___MsgUpgradeClient,
        global___MsgUpgradeClientResponse] = ...

    SubmitMisbehaviour:grpc.UnaryUnaryMultiCallable[
        global___MsgSubmitMisbehaviour,
        global___MsgSubmitMisbehaviourResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateClient(self,
        request: global___MsgCreateClient,
        context: grpc.ServicerContext,
    ) -> global___MsgCreateClientResponse: ...

    @abc.abstractmethod
    def UpdateClient(self,
        request: global___MsgUpdateClient,
        context: grpc.ServicerContext,
    ) -> global___MsgUpdateClientResponse: ...

    @abc.abstractmethod
    def UpgradeClient(self,
        request: global___MsgUpgradeClient,
        context: grpc.ServicerContext,
    ) -> global___MsgUpgradeClientResponse: ...

    @abc.abstractmethod
    def SubmitMisbehaviour(self,
        request: global___MsgSubmitMisbehaviour,
        context: grpc.ServicerContext,
    ) -> global___MsgSubmitMisbehaviourResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.applications.transfer.v1.transfer_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryDenomTraceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HASH_FIELD_NUMBER: builtins.int
    hash: typing.Text = ...

    def __init__(self,
        *,
        hash : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash"]) -> None: ...
global___QueryDenomTraceRequest = QueryDenomTraceRequest

class QueryDenomTraceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_TRACE_FIELD_NUMBER: builtins.int

    @property
    def denom_trace(self) -> ibc.applications.transfer.v1.transfer_pb2.DenomTrace: ...

    def __init__(self,
        *,
        denom_trace : typing.Optional[ibc.applications.transfer.v1.transfer_pb2.DenomTrace] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"denom_trace",b"denom_trace"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom_trace",b"denom_trace"]) -> None: ...
global___QueryDenomTraceResponse = QueryDenomTraceResponse

class QueryDenomTracesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___QueryDenomTracesRequest = QueryDenomTracesRequest

class QueryDenomTracesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DENOM_TRACES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def denom_traces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.applications.transfer.v1.transfer_pb2.DenomTrace]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        denom_traces : typing.Optional[typing.Iterable[ibc.applications.transfer.v1.transfer_pb2.DenomTrace]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"denom_traces",b"denom_traces",u"pagination",b"pagination"]) -> None: ...
global___QueryDenomTracesResponse = QueryDenomTracesResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> ibc.applications.transfer.v1.transfer_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[ibc.applications.transfer.v1.transfer_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class App(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PROTOCOL_FIELD_NUMBER: builtins.int
    SOFTWARE_FIELD_NUMBER: builtins.int
    protocol: builtins.int = ...
    software: typing.Text = ...

    def __init__(self,
        *,
        protocol : builtins.int = ...,
        software : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"protocol",b"protocol",u"software",b"software"]) -> None: ...
global___App = App

class Consensus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BLOCK_FIELD_NUMBER: builtins.int
    APP_FIELD_NUMBER: builtins.int
    block: builtins.int = ...
    app: builtins.int = ...

    def __init__(self,
        *,
        block : builtins.int = ...,
        app : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"app",b"app",u"block",b"block"]) -> None: ...
global___Consensus = Consensus



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    RequestData:grpc.UnaryUnaryMultiCallable[
        global___MsgRequestData,
        global___MsgRequestDataResponse] = ...

    ReportData:grpc.UnaryUnaryMultiCallable[
        global___MsgReportData,
        global___MsgReportDataResponse] = ...

    CreateDataSource:grpc.UnaryUnaryMultiCallable[
        global___MsgCreateDataSource,
        global___MsgCreateDataSourceResponse] = ...

    EditDataSource:grpc.UnaryUnaryMultiCallable[
        global___MsgEditDataSource,
        global___MsgEditDataSourceResponse] = ...

    CreateOracleScript:grpc.UnaryUnaryMultiCallable[
        global___MsgCreateOracleScript,
        global___MsgCreateOracleScriptResponse] = ...

    EditOracleScript:grpc.UnaryUnaryMultiCallable[
        global___MsgEditOracleScript,
        global___MsgEditOracleScriptResponse] = ...

    Activate:grpc.UnaryUnaryMultiCallable[
        global___MsgActivate,
        global___MsgActivateResponse] = ...

    AddReporter:grpc.UnaryUnaryMultiCallable[
        global___MsgAddReporter,
        global___MsgAddReporterResponse] = ...

    RemoveReporter:grpc.UnaryUnaryMultiCallable[
        global___MsgRemoveReporter,
        global___MsgRemoveReporterResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def RequestData(self,
        request: global___MsgRequestData,
        context: grpc.ServicerContext,
    ) -> global___MsgRequestDataResponse: ...

    @abc.abstractmethod
    def ReportData(self,
        request: global___MsgReportData,
        context: grpc.ServicerContext,
    ) -> global___MsgReportDataResponse: ...

    @abc.abstractmethod
    def CreateDataSource(self,
        request: global___MsgCreateDataSource,
        context: grpc.ServicerContext,
    ) -> global___MsgCreateDataSourceResponse: ...

    @abc.abstractmethod
    def EditDataSource(self,
        request: global___MsgEditDataSource,
        context: grpc.ServicerContext,
    ) -> global___MsgEditDataSourceResponse: ...

    @abc.abstractmethod
    def CreateOracleScript(self,
        request: global___MsgCreateOracleScript,
        context: grpc.ServicerContext,
    ) -> global___MsgCreateOracleScriptResponse: ...

    @abc.abstractmethod
    def EditOracleScript(self,
        request: global___MsgEditOracleScript,
        context: grpc.ServicerContext,
    ) -> global___MsgEditOracleScriptResponse: ...

    @abc.abstractmethod
    def Activate(self,
        request: global___MsgActivate,
        context: grpc.ServicerContext,
    ) -> global___MsgActivateResponse: ...

    @abc.abstractmethod
    def AddReporter(self,
        request: global___MsgAddReporter,
        context: grpc.ServicerContext,
    ) -> global___MsgAddReporterResponse: ...

    @abc.abstractmethod
    def RemoveReporter(self,
        request: global___MsgRemoveReporter,
        context: grpc.ServicerContext,
    ) -> global___MsgRemoveReporterResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateValidator:grpc.UnaryUnaryMultiCallable[
        global___MsgCreateValidator,
        global___MsgCreateValidatorResponse] = ...

    EditValidator:grpc.UnaryUnaryMultiCallable[
        global___MsgEditValidator,
        global___MsgEditValidatorResponse] = ...

    Delegate:grpc.UnaryUnaryMultiCallable[
        global___MsgDelegate,
        global___MsgDelegateResponse] = ...

    BeginRedelegate:grpc.UnaryUnaryMultiCallable[
        global___MsgBeginRedelegate,
        global___MsgBeginRedelegateResponse] = ...

    Undelegate:grpc.UnaryUnaryMultiCallable[
        global___MsgUndelegate,
        global___MsgUndelegateResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateValidator(self,
        request: global___MsgCreateValidator,
        context: grpc.ServicerContext,
    ) -> global___MsgCreateValidatorResponse: ...

    @abc.abstractmethod
    def EditValidator(self,
        request: global___MsgEditValidator,
        context: grpc.ServicerContext,
    ) -> global___MsgEditValidatorResponse: ...

    @abc.abstractmethod
    def Delegate(self,
        request: global___MsgDelegate,
        context: grpc.ServicerContext,
    ) -> global___MsgDelegateResponse: ...

    @abc.abstractmethod
    def BeginRedelegate(self,
        request: global___MsgBeginRedelegate,
        context: grpc.ServicerContext,
    ) -> global___MsgBeginRedelegateResponse: ...

    @abc.abstractmethod
    def Undelegate(self,
        request: global___MsgUndelegate,
        context: grpc.ServicerContext,
    ) -> global___MsgUndelegateResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    GEN_TXS_FIELD_NUMBER: builtins.int

    @property
    def gen_txs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        gen_txs : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"gen_txs",b"gen_txs"]) -> None: ...
global___GenesisState = GenesisState
